@@ -6,6 +6,7 @@ More detailed description.
 """
 
 import multiprocessing as mp
+import warnings
 
 from pyrasta.crs import proj4_from
 from pyrasta.io_.files import _copy_to_file
@@ -48,8 +49,11 @@ class RasterBase:
 
         # If NoData not defined, define here
         for band in range(self.nb_band):
-            if self._gdal_dataset.GetRasterBand(band + 1).GetNoDataValue() is None:
-                self._gdal_dataset.GetRasterBand(band + 1).SetNoDataValue(no_data)
+            if no_data is not None:
+                if self._gdal_dataset.GetRasterBand(band + 1).GetNoDataValue() is None:
+                    self._gdal_dataset.GetRasterBand(band + 1).SetNoDataValue(no_data)
+                else:
+                    warnings.warn("No data value is already set, cannot overwrite.")
 
         self._gdal_driver = self._gdal_dataset.GetDriver()
         self._file = src_file
@@ -185,7 +189,9 @@ class RasterBase:
 
     @classmethod
     def merge_bands(cls, rasters, resolution="highest",
-                    gdal_driver=gdal.GetDriverByName("Gtiff"), no_data=-999):
+                    gdal_driver=gdal.GetDriverByName("Gtiff"),
+                    data_type=gdal.GetDataTypeByName('Float32'),
+                    no_data=-999):
         """ Create one single raster from multiple bands
 
         Description
@@ -199,10 +205,12 @@ class RasterBase:
         resolution: str
             GDAL resolution option ("highest", "lowest", "average")
         gdal_driver: osgeo.gdal.Driver
+        data_type: int
+            GDAL data type
         no_data: int or float
             no data value in output raster
         """
-        return _merge_bands(cls, rasters, resolution, gdal_driver, no_data)
+        return _merge_bands(cls, rasters, resolution, gdal_driver, data_type, no_data)
 
     def pad_extent(self, pad_x, pad_y, value):
         """ Pad raster extent with given values
@@ -270,10 +278,10 @@ class RasterBase:
                           all_touched)
 
     @classmethod
-    def raster_calculation(cls, rasters, fhandle, window_size=1000,
+    def raster_calculation(cls, rasters, fhandle, window_size=100,
                            gdal_driver=gdal.GetDriverByName("Gtiff"),
                            data_type=gdal.GetDataTypeByName('Float32'),
-                           no_data=-999, showprogressbar=True, **kwargs):
+                           no_data=-999, nb_processes=mp.cpu_count()):
         """ Raster expression calculation
 
         Description
@@ -287,7 +295,7 @@ class RasterBase:
         rasters: list or tuple
             collection of RasterBase instances
         fhandle: function
-            expression to calculate
+            expression to calculate (must accept a collection of arrays)
         window_size: int
             size of window/chunk to set in memory during calculation
         gdal_driver: osgeo.gdal.Driver
@@ -296,18 +304,16 @@ class RasterBase:
             GDAL data type for output raster
         no_data: int or float
             no data value in resulting raster
-        showprogressbar: bool
-            if True, show progress bar
-        kwargs:
-            fhandle keyword arguments (if any)
+        nb_processes: int
+            number of processes for multiprocessing pool
 
         Returns
         -------
-        RasterBase:
+        RasterBase
             New temporary instance
         """
         return _raster_calculation(cls, rasters, fhandle, window_size,
-                                   gdal_driver, data_type, no_data, showprogressbar, **kwargs)
+                                   gdal_driver, data_type, no_data, nb_processes)
 
     def read_array(self, band=None, bounds=None):
         """ Write raster to numpy array
@@ -358,7 +364,7 @@ class RasterBase:
 
         Returns
         -------
-        RasterBase:
+        RasterBase
             New temporary resampled instance
         """
         return _resample_raster(self, factor)
@@ -376,8 +382,8 @@ class RasterBase:
         r_max: int or float
             maximum value of new range
 
-        Return
-        ------
+        Returns
+        -------
         """
         return _rescale_raster(self, r_min, r_max)
 
@@ -440,7 +446,7 @@ class RasterBase:
 
         Return
         ------
-        RasterBase:
+        RasterBase
             New instance
 
         """
